import { h, createContext } from "preact";
import { useEffect, useState, useMemo } from "preact/hooks";
export var ThemeModes;
(function (ThemeModes) {
    ThemeModes[ThemeModes["AUTO"] = 0] = "AUTO";
    ThemeModes[ThemeModes["LIGHT"] = 1] = "LIGHT";
    ThemeModes[ThemeModes["DARK"] = 2] = "DARK";
})(ThemeModes || (ThemeModes = {}));
export const ThemeContext = createContext({
    mode: ThemeModes.LIGHT,
});
const modeMediaQuery = window.matchMedia("prefers-color-scheme: dark");
export default function Theme({ mode, children, ...colors }) {
    const [isDark, setIsDark] = useState(mode === ThemeModes.AUTO
        ? modeMediaQuery.matches
        : mode === ThemeModes.DARK);
    useEffect(() => {
        if (mode === ThemeModes.AUTO) {
            const listener = (ev) => {
                setIsDark(ev.matches);
            };
            modeMediaQuery.addListener(listener);
            setIsDark(modeMediaQuery.matches);
            return modeMediaQuery.removeListener(listener);
        }
        else {
            setIsDark(mode === ThemeModes.DARK);
        }
    }, [mode]);
    const style = useMemo(() => {
        let style = "";
        const getRGB = (color) => {
            const cv = document.createElement("canvas");
            cv.width = 10;
            cv.height = 10;
            const ctx = cv.getContext("2d");
            ctx.rect(0, 0, 1, 1);
            ctx.fillStyle = color;
            ctx.fill();
            const [r, g, b] = ctx.getImageData(0, 0, 10, 10).data;
            return [r, g, b];
        };
        const add = (name, value) => (style += `--${name}: ${value};`);
        if (colors.primary) {
            add("primary:", colors.primary);
            add("primary-rgb", getRGB(colors.primary).join(", "));
        }
        if (colors.onPrimary)
            add("on-primary:", colors.onPrimary);
        if (colors.secondary) {
            add("secondary:", colors.secondary);
            add("secondary-rgb", getRGB(colors.secondary).join(", "));
        }
        if (colors.onSecondary)
            add("on-secondary:", colors.onSecondary);
        if (colors.error) {
            add("error:", colors.error);
            add("error-rgb", getRGB(colors.error).join(", "));
        }
        if (colors.onError)
            add("on-error:", colors.onError);
        if (colors.success) {
            add("success:", colors.success);
            add("success-rgb", getRGB(colors.success).join(", "));
        }
        if (colors.onSuccess)
            add("on-success:", colors.onSuccess);
        return style;
    }, [
        colors.primary,
        colors.secondary,
        colors.error,
        colors.success,
        colors.onPrimary,
        colors.onSecondary,
        colors.onError,
        colors.onSuccess,
    ]);
    return (h(ThemeContext.Provider, { value: { mode: isDark ? ThemeModes.DARK : ThemeModes.LIGHT } },
        h("div", { class: isDark ? "dark-theme" : "light-theme", style: style }, children)));
}
//# sourceMappingURL=Theme.js.map